"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var readline_1 = require("readline");
/**
 * Create a simple y/n prompt for the terminal
 *
 * Adapted from create-react-app's prompt
 * @example
 * prompt('Do the thing?') // with 'no' default
 * prompt('Do the thing?', true) // with 'yes' default
 */
var termPrompt = function (question, isYesDefault) {
    if (isYesDefault === void 0) { isYesDefault = false; }
    return new Promise(function (resolve) {
        var rlInterface = readline_1.createInterface({
            input: process.stdin,
            output: process.stdout,
        });
        var hint = isYesDefault ? '[Y/n]' : '[y/N]';
        var message = question + " " + hint + "\n";
        rlInterface.question(message, function (answer) {
            rlInterface.close();
            var useDefault = answer.trim().length === 0;
            if (useDefault) {
                return resolve(isYesDefault);
            }
            var isYes = answer.match(/^(yes|y)$/i);
            return resolve(!!isYes);
        });
    });
};
exports.default = termPrompt;
